==> mdi-react-1.2.0.tgz: package/RadioactiveCircleIcon.js <==
'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));
var uuid = require('uuid');

var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var objectWithoutProperties = function (obj, keys) {
  var target = {};

  for (var i in obj) {
    if (keys.indexOf(i) >= 0) continue;
    if (!Object.prototype.hasOwnProperty.call(obj, i)) continue;
    target[i] = obj[i];
  }

  return target;
};

var RadioactiveCircleIcon = function RadioactiveCircleIcon(_ref) {
  var _ref$color = _ref.color,
      color = _ref$color === undefined ? 'currentColor' : _ref$color,
      _ref$size = _ref.size,
      size = _ref$size === undefined ? 24 : _ref$size,
      children = _ref.children,
      title = _ref.title,
      props = objectWithoutProperties(_ref, ['color', 'size', 'children', 'title']);

  var className = 'mdi-icon ' + (props.className || '');
  var titleId = title ? title.id ? title.id : uuid.v4() : null;

  return React.createElement(
    'svg',
    _extends({}, props, { 'aria-labelledby': titleId, className: className, width: size, height: size, fill: color, viewBox: '0 0 24 24' }),
    title && React.createElement(
      'title',
      { id: titleId },
      title.name
    ),
    React.createElement('path', { d: 'M12 2C6.5 2 2 6.5 2 12S6.5 22 12 22 22 17.5 22 12 17.5 2 12 2M12 10C13.11 10 14 10.9 14 12S13.11 14 12 14 10 13.11 10 12 10.9 10 12 10M4 12C4 8.7 6 5.87 8.86 4.64L10.34 8.36C8.96 9 8 10.38 8 12H4M12 20C10.46 20 9 19.56 7.8 18.8L10 15.47C10.6 15.81 11.28 16 12 16S13.4 15.81 14 15.47L16.2 18.8C15 19.56 13.54 20 12 20M16 12C16 10.38 15.04 9 13.66 8.36L15.15 4.64C18 5.87 20 8.7 20 12H16Z' })
  );
};

var RadioactiveCircleIcon$1 = React.memo ? React.memo(RadioactiveCircleIcon) : RadioactiveCircleIcon;

module.exports = RadioactiveCircleIcon$1;

==> mdi-react-8.4.0.tgz: package/RadioactiveCircleIcon.js <==
'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = _interopDefault(require('react'));

var _extends = Object.assign || function (target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i];

    for (var key in source) {
      if (Object.prototype.hasOwnProperty.call(source, key)) {
        target[key] = source[key];
      }
    }
  }

  return target;
};

var objectWithoutProperties = function (obj, keys) {
  var target = {};

  for (var i in obj) {
    if (keys.indexOf(i) >= 0) continue;
    if (!Object.prototype.hasOwnProperty.call(obj, i)) continue;
    target[i] = obj[i];
  }

  return target;
};

var RadioactiveCircleIcon = function RadioactiveCircleIcon(_ref) {
  var _ref$color = _ref.color,
      color = _ref$color === undefined ? 'currentColor' : _ref$color,
      _ref$size = _ref.size,
      size = _ref$size === undefined ? 24 : _ref$size,
      children = _ref.children,
      props = objectWithoutProperties(_ref, ['color', 'size', 'children']);

  var className = 'mdi-icon ' + (props.className || '');

  return React.createElement(
    'svg',
    _extends({}, props, { className: className, width: size, height: size, fill: color, viewBox: '0 0 24 24' }),
    React.createElement('path', { d: 'M12 2C6.5 2 2 6.5 2 12S6.5 22 12 22 22 17.5 22 12 17.5 2 12 2M12 10C13.11 10 14 10.9 14 12S13.11 14 12 14 10 13.11 10 12 10.9 10 12 10M4 12C4 8.7 6 5.87 8.86 4.64L10.34 8.36C8.96 9 8 10.38 8 12H4M12 20C10.46 20 9 19.56 7.8 18.8L10 15.47C10.6 15.81 11.28 16 12 16S13.4 15.81 14 15.47L16.2 18.8C15 19.56 13.54 20 12 20M16 12C16 10.38 15.04 9 13.66 8.36L15.15 4.64C18 5.87 20 8.7 20 12H16Z' })
  );
};

var RadioactiveCircleIcon$1 = React.memo ? React.memo(RadioactiveCircleIcon) : RadioactiveCircleIcon;

module.exports = RadioactiveCircleIcon$1;
